@@ -26,6 +26,13 @@ APPLICATION_ID = 'org.x.sticky'
 STYLE_SHEET_PATH = '/usr/share/sticky/sticky.css'
 SCHEMA = 'org.x.sticky'
 
+FONT_SCALES = [
+    ('small', _("Small Text"), 'small'),
+    ('normal', _("Normal Text"), 'medium'),
+    ('large', _("Large Text"), 'large'),
+    ('larger', _("Larger Text"), 'x-large')
+]
+
 COLORS = {
     'red': _("Red"),
     'green': _("Green"),
@@ -48,21 +55,25 @@ COLOR_CODES = {
     'magenta': "#ff7ff7"
 }
 
-SHORTCUTS = [
-    (_("Move selection up"), '<ctrl><shift>Up'),
-    (_("Move selection down"), '<ctrl><shift>Down'),
-    (_("Undo"), '<ctrl>z'),
-    (_("Redo"), '<ctrl>y'),
-    (_("Toggle Checklist"), '<ctrl>e'),
-    (_("Toggle Bullets"), '<ctrl>l'),
-    (_("Bold"), '<ctrl>b'),
-    (_("Italic"), '<ctrl>i'),
-    (_("Fixed Width"), '<ctrl>f'),
-    (_("Underline"), '<ctrl>u'),
-    (_("Strikethrough"), '<ctrl>k'),
-    (_("Highlight"), '<ctrl>g'),
-    (_("Header"), '<ctrl>h')
-]
+SHORTCUTS = {
+    _("Operations"): [
+        (_("Move selection up"), '<ctrl><shift>Up'),
+        (_("Move selection down"), '<ctrl><shift>Down'),
+        (_("Undo"), '<ctrl>z'),
+        (_("Redo"), '<ctrl>y'),
+        (_("Toggle Checklist"), '<ctrl>e'),
+        (_("Toggle Bullets"), '<ctrl>l')
+    ],
+    _("Formatting"): [
+        (_("Bold"), '<ctrl>b'),
+        (_("Italic"), '<ctrl>i'),
+        (_("Fixed Width"), '<ctrl>f'),
+        (_("Underline"), '<ctrl>u'),
+        (_("Strikethrough"), '<ctrl>k'),
+        (_("Highlight"), '<ctrl>g'),
+        (_("Header"), '<ctrl>h')
+    ]
+}
 
 class Note(Gtk.Window):
     @GObject.Signal(flags=GObject.SignalFlags.RUN_LAST, return_type=bool,
@@ -116,7 +127,7 @@ class Note(Gtk.Window):
         color_icon = Gtk.Image.new_from_icon_name('sticky-color', Gtk.IconSize.BUTTON)
         color_button = Gtk.MenuButton(image=color_icon, relief=Gtk.ReliefStyle.NONE, name='window-button', valign=Gtk.Align.CENTER)
         color_button.connect('button-press-event', self.on_title_click)
-        color_button.set_tooltip_text(_("Format"))
+        color_button.set_tooltip_text(_("Note Color"))
         self.title_bar.pack_start(color_button, False, False, 0)
 
         # used to show the edit title icon when the title is hovered
@@ -273,6 +284,22 @@ class Note(Gtk.Window):
                 self.buffer.tag_selection('highlight')
                 return Gdk.EVENT_STOP
 
+            elif event.get_keyval()[1] == Gdk.KEY_2:
+                self.buffer.tag_selection('small')
+                return Gdk.EVENT_STOP
+
+            elif event.get_keyval()[1] == Gdk.KEY_3:
+                self.buffer.tag_selection('normal')
+                return Gdk.EVENT_STOP
+
+            elif event.get_keyval()[1] == Gdk.KEY_4:
+                self.buffer.tag_selection('large')
+                return Gdk.EVENT_STOP
+
+            elif event.get_keyval()[1] == Gdk.KEY_5:
+                self.buffer.tag_selection('larger')
+                return Gdk.EVENT_STOP
+
         elif event.keyval in (Gdk.KEY_Return, Gdk.KEY_ISO_Enter, Gdk.KEY_KP_Enter):
             return self.buffer.on_return()
 
@@ -418,6 +445,14 @@ class Note(Gtk.Window):
 
         menu.append(Gtk.SeparatorMenuItem(visible=True))
 
+        for (scale_id, scale_name, scale_value) in FONT_SCALES:
+            font_scale_item = Gtk.MenuItem(label=scale_name, visible=True)
+            font_scale_item.get_child().set_markup("<span size='%s'>%s</span>" % (scale_value, scale_name))
+            font_scale_item.connect('activate', self.apply_format, scale_id)
+            menu.append(font_scale_item)
+
+        menu.append(Gtk.SeparatorMenuItem(visible=True))
+
         self.checklist_item = Gtk.MenuItem(label="\u25A2 %s" % _("Toggle Checklist"), visible=True)
         self.checklist_item.connect('activate', self.buffer.toggle_checklist)
         menu.append(self.checklist_item)
@@ -556,11 +591,18 @@ class ShortcutsWindow(Gtk.ShortcutsWindow):
 
         section = Gtk.ShortcutsSection(visible=True)
 
-        group = Gtk.ShortcutsGroup(title='', visible=False)
-        section.add(group)
+        for group, items in SHORTCUTS.items():
+            group = Gtk.ShortcutsGroup(title=group, visible=False)
+            section.add(group)
 
-        for shortcut in SHORTCUTS:
-            shortcut_item = Gtk.ShortcutsShortcut(title=shortcut[0], accelerator=shortcut[1], visible=True)
+            for shortcut in items:
+                shortcut_item = Gtk.ShortcutsShortcut(title=shortcut[0], accelerator=shortcut[1], visible=True)
+                group.add(shortcut_item)
+
+        group = Gtk.ShortcutsGroup(title=_("Text Size"), visible=False)
+        section.add(group)
+        for i in range(len(FONT_SCALES)):
+            shortcut_item = Gtk.ShortcutsShortcut(title=FONT_SCALES[i][1], accelerator='<ctrl>%d' % (i + 2), visible=True)
             group.add(shortcut_item)
 
         self.add(section)
@@ -576,6 +618,9 @@ class Application(Gtk.Application):
         self.notes = []
         self.settings_window = None
         self.keyboard_shortcuts = None
+        # There's no use creating the manager if a user is never going to use it, so we don't until it's asked for.
+        # Therefore, we should never assume that the manager already exists, and handle the situation gracefully if it
+        # is none.
         self.manager = None
         self.notes_hidden = False
         self.autostart_mode = False # indicates if we're in autostart mode
@@ -687,7 +732,9 @@ class Application(Gtk.Application):
         self.status_icon = XApp.StatusIcon()
         self.status_icon.set_name('sticky')
         self.status_icon.set_icon_name('sticky-symbolic')
-        self.status_icon.set_tooltip_text(_('Notes'))
+        self.status_icon.set_tooltip_text('%s\n<i>%s</i>\n<i>%s</i>' % (_("Notes"),
+                                                                        _("Left click to toggle notes"),
+                                                                        _("Middle click to toggle the manager")))
         self.status_icon.set_visible(True)
         self.status_icon.connect('button-press-event', self.on_tray_button_pressed)
         self.status_icon.connect('button-release-event', self.on_tray_button_released)
@@ -695,6 +742,8 @@ class Application(Gtk.Application):
     def on_tray_button_pressed(self, icon, x, y , button, time, panel_position):
         if button == 1:
             self.activate_notes(time)
+        elif button == 2:
+            self.toggle_manager(time)
 
     def on_tray_button_released(self, icon, x, y , button, time, panel_position):
       if button == 3:
@@ -791,6 +840,13 @@ class Application(Gtk.Application):
         info = {'x': x, 'y': y}
         note = self.generate_note(info)
         note.present_with_time(Gtk.get_current_event_time())
+
+        # Note is Gdk.WindowType.UTILITY - these don't get raised automatically
+        # (see muffin: window.c:window_state_on_map)
+        if not note.get_realized():
+            note.realize()
+        note.get_window().raise_()
+
         note.changed()
 
     def generate_note(self, info={}):
@@ -811,6 +867,11 @@ class Application(Gtk.Application):
         for note_info in self.file_handler.get_note_list(self.note_group):
             self.generate_note(note_info)
 
+    def focus_note(self, note_info):
+        for note in self.notes:
+            if note.get_info() == note_info:
+                note.present_with_time(0)
+
     def on_lists_changed(self, *args):
         if not self.note_group in self.file_handler.get_note_group_names():
             self.change_visible_note_group()
@@ -845,19 +906,30 @@ class Application(Gtk.Application):
 
         self.load_notes()
 
-    def open_manager(self, *args):
+    def open_manager(self, *args, time=0):
         if self.manager:
-            self.manager.window.present_with_time(Gtk.get_current_event_time())
+            if time == 0:
+                time = Gtk.get_current_event_time()
+            self.manager.window.present_with_time(time)
             return
 
         self.manager = NotesManager(self, self.file_handler)
-        self.manager.window.connect('destroy', self.manager_closed)
+        self.manager.window.connect('delete-event', self.manager_closed)
+
+    def toggle_manager(self, time):
+        if self.manager and self.manager.window.is_active() and self.manager.window.is_visible():
+            self.manager.window.hide()
+        else:
+            self.open_manager(time=time)
 
     def manager_closed(self, *args):
-        self.manager = None
         if self.status_icon is None:
             self.quit_app()
 
+        self.manager.window.hide()
+
+        return Gdk.EVENT_STOP
+
     def open_settings_window(self, *args):
         if self.settings_window:
             self.settings_window.present_with_time(Gtk.get_current_event_time())
